#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void _aB_K__0__G__1___TwoPRep_S__0__F__1___Ab__up_0(const Libint_t* inteval);
#ifdef __cplusplus
};
#endif
